@@ -15,15 +15,34 @@ OC.L10N.register(
     "SMTP Port" : "SMTP-poort",
     "SMTP User" : "SMTP-gebruiker",
     "SMTP Password" : "SMTP-wagwoord",
+    "Save" : "Stoor",
+    "Connect" : "Verbind",
     "Add mail account" : "Voeg posrekening toe",
+    "Keyboard shortcuts" : "Sneltoetse",
+    "Copy" : "Kopieer",
     "Subject" : "Onderwerp",
     "Sending …" : "Stuur…",
+    "Go back" : "Gaan terug",
+    "Retry" : "Herprobeer",
     "Message sent!" : "Boodskap gestuur!",
     "Send" : "Stuur",
+    "Delete" : "Skrap",
+    "Reply" : "Antwoord",
+    "Forward" : "Stuur aan",
     "Import into calendar" : "Voer in na kalender",
     "Download attachment" : "Laai aanhangsel af",
     "New message" : "Nuwe boodskap",
     "Settings" : "Instellings",
+    "Add folder" : "Voeg 'n gids by",
+    "Delete account" : "Skrap rekening",
+    "Loading …" : "Laai …",
+    "Signature" : "Handtekening",
+    "General" : "Algemeen",
+    "User" : "Gebruiker",
+    "Host" : "Gasheer",
+    "Port" : "Poort",
+    "Search" : "Soek",
+    "Refresh" : "Verfris",
     "Connect your mail account" : "Koppel u posrekening",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Forwarding to %s" : "Stuur aan na %s",
