@@ -12,6 +12,7 @@ OC.L10N.register(
     "IMAP Settings" : "إعدادات IMAP",
     "IMAP Host" : "مُضيف IMAP",
     "None" : "بلا",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "منفذ IMAP",
     "IMAP User" : "مستخدم IMAP",
@@ -25,6 +26,8 @@ OC.L10N.register(
     "Connect" : "اتصال",
     "Add mail account" : "أضف حساب بريدي",
     "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
+    "Select account" : "إختيار حساب",
+    "Copy" : "أنسخ",
     "Subject" : "الموضوع",
     "Upload attachment" : "رفع المرفقات",
     "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
@@ -37,6 +40,8 @@ OC.L10N.register(
     "Draft: " : "المسودة:",
     "Delete" : "حذف",
     "Not found" : "غير موجود",
+    "Reply" : "رد",
+    "Forward" : "إعادة توجيه ",
     "Could not load your message" : "تعذرت عملية تحميل رسالتك",
     "Import into calendar" : "إستيراد من التقويم",
     "Download attachment" : "تنزيل الملحق",
@@ -47,9 +52,16 @@ OC.L10N.register(
     "New message" : "رسالة جديدة",
     "Settings" : "الإعدادات",
     "Add folder" : "إضافة مجلد",
+    "Delete account" : "حذف الحساب",
     "Show all folders" : "أظهر جميع المجلدات",
     "Collapse folders" : "طي المجلدات",
+    "Mark all as read" : "تحديد الكل كمقروء",
     "Signature" : "التوقيع",
+    "General" : "العامة",
+    "Email address" : "عنوان البريد الإلكتروني",
+    "User" : "المستخدم",
+    "Host" : "المضيف",
+    "Port" : "المنفذ",
     "Mail server" : "خادم البريد",
     "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
     "Compose new message" : "إرسل رسالة جديدة",
