@@ -82,11 +82,12 @@ OC.L10N.register(
     "New message" : "Nou missatge",
     "Settings" : "Paràmetres",
     "Edit account" : "Edita el compte",
-    "Delete account" : "Suprimeix el compte",
     "Add folder" : "Afegeix una carpeta",
+    "Delete account" : "Suprimeix el compte",
     "Show all folders" : "Mostra totes les carpetes",
     "Collapse folders" : "Replega les carpetes",
     "Mark all as read" : "Marca-ho tot com a llegit",
+    "Mark all messages of this folder as read" : "Marca tots els missatges d'aquesta carpeta com a llegits",
     "Add subfolder" : "Afegeix una subcarpeta",
     "{total} messages" : "{total} missatges",
     "{unread} unread of {total}" : "{unread} no llegits de {total}",
@@ -95,6 +96,11 @@ OC.L10N.register(
     "Could not load original message" : "No s'ha pogut carregar el missatge original",
     "No message selected" : "No s'ha seleccionat cap missatge",
     "Signature" : "Signatura",
+    "General" : "General",
+    "Email address" : "Adreça de correu electrònic",
+    "User" : "Usuari",
+    "Host" : "Servidor",
+    "Port" : "Port",
     "Account settings" : "Paràmetres del compte",
     "Change name" : "Canvia el nom",
     "Mail server" : "Servidor de correu electrònic",
