@@ -10,6 +10,7 @@ OC.L10N.register(
     "Password" : "Password",
     "IMAP Host" : "IMAP Host",
     "None" : "None",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP Port",
     "IMAP User" : "IMAP User",
@@ -18,19 +19,28 @@ OC.L10N.register(
     "SMTP Port" : "SMTP Port",
     "SMTP User" : "SMTP User",
     "SMTP Password" : "SMTP Password",
+    "Save" : "Save",
     "Connect" : "Connect",
     "Add mail account" : "Add mail account",
     "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
     "Keyboard shortcuts" : "Keyboard shortcuts",
+    "Select account" : "Select account",
+    "Copy" : "Copy",
     "Subject" : "Subject",
     "Upload attachment" : "Upload attachment",
     "Add attachment from Files" : "Add attachment from Files",
     "Sending …" : "Sending…",
+    "Go back" : "Go back",
+    "Retry" : "Retry",
     "Message sent!" : "Message sent!",
     "Send" : "Send",
     "Choose a file to add as attachment" : "Choose a file to add as attachment",
     "No messages in this folder" : "No messages in this folder",
+    "Mark read" : "Mark read",
     "Delete" : "Delete",
+    "Not found" : "Not found",
+    "Reply" : "Reply",
+    "Forward" : "Forward",
     "Could not load your message" : "Could not load your message",
     "Import into calendar" : "Import into calendar",
     "Download attachment" : "Download attachment",
@@ -40,8 +50,16 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "The images have been blocked to protect your privacy.",
     "New message" : "New message",
     "Settings" : "Settings",
+    "Add folder" : "Add folder",
+    "Delete account" : "Delete account",
     "Show all folders" : "Show all folders",
     "Collapse folders" : "Collapse folders",
+    "Mark all as read" : "Mark all as read",
+    "Signature" : "Signature",
+    "General" : "General",
+    "User" : "User",
+    "Host" : "Host",
+    "Port" : "Port",
     "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
     "Compose new message" : "Compose new message",
     "Newer message" : "Newer message",
