@@ -31,6 +31,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ĉu vi serĉas manieron ĉifri viajn mesaĝojn? Instalu la retumilan kromprogramon „Mailvelope“!",
+    "Copy" : "Kopii",
     "Subject" : "Temo",
     "Saving draft …" : "Konservado de malneto...",
     "Draft saved" : "Malneto konservita",
@@ -55,6 +56,8 @@ OC.L10N.register(
     "Report this bug" : "Raporti tiun problemon",
     "Loading messages" : "Ŝargo de mesaĝoj",
     "Not found" : "Ne trovita",
+    "Reply" : "Respondi",
+    "Forward" : "Antaŭen",
     "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
     "Import into calendar" : "Importi en kalendaron",
     "Download attachment" : "Elŝuti kunsendaĵon",
@@ -67,13 +70,20 @@ OC.L10N.register(
     "New message" : "Nova mesaĝo",
     "Settings" : "Agordoj",
     "Add folder" : "Aldoni dosierujon",
+    "Delete account" : "Forigi konton",
     "Show all folders" : "Montri ĉiujn dosierujojn",
     "Collapse folders" : "Maletendi dosierujojn",
     "Mark all as read" : "Marki ĉion kiel legita",
+    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
     "Add subfolder" : "Aldoni subdosierujon",
+    "Loading …" : "Ŝargado...",
     "Could not load your draft" : "Ne eblis ŝargi vian malneton",
     "No message selected" : "Neniu mesaĝo elektita",
     "Signature" : "Subskribo",
+    "General" : "Ĝenerala",
+    "User" : "Uzanto",
+    "Host" : "Gastigo",
+    "Port" : "Pordo",
     "Mail server" : "Retpoŝtoservilo",
     "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
     "Compose new message" : "Krei novan mesaĝon",
