@@ -10,6 +10,7 @@ OC.L10N.register(
     "Password" : "Contraseña",
     "IMAP Host" : "Servidor IMAP",
     "None" : "Ninguno",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "Puerto IMAP",
     "IMAP User" : "Usuario IMAP",
@@ -18,15 +19,24 @@ OC.L10N.register(
     "SMTP Port" : "Puerto SMTP",
     "SMTP User" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar",
     "Connect" : "Conectar",
     "Add mail account" : "Agregar cuenta de correo",
     "Keyboard shortcuts" : "Atajos de teclado",
+    "Select account" : "Seleccione la cuenta",
+    "Copy" : "Copiar",
     "Subject" : "Asunto",
+    "Add attachment from Files" : "Agregar adjunto desde Archivos",
     "Sending …" : "Enviando ...",
+    "Go back" : "Regresar",
+    "Retry" : "Reintentar",
     "Message sent!" : "¡Mensaje enviado!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
+    "Mark read" : "Marcar como leído",
     "Delete" : "Borrar",
+    "Reply" : "Responder",
+    "Forward" : "Reenviar",
     "Could not load your message" : "No se pudo cargar tu mensaje",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
@@ -36,12 +46,22 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger su privacidad. ",
     "New message" : "Mensaje nuevo",
     "Settings" : "Configuraciones ",
+    "Add folder" : "Agregar carpeta",
+    "Delete account" : "Borrar cuenta",
     "Show all folders" : "Mostrar todos las carpetas",
     "Collapse folders" : "Compactar carpetas",
+    "Mark all as read" : "Marcar todos como leídos",
+    "Signature" : "Firma",
+    "General" : "General",
+    "User" : "Usuario",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
     "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de correo con estos atajos rápidos.",
     "Compose new message" : "Redactar nuevo mensaje",
     "Newer message" : "Mensaje mas nuevo",
     "Older message" : "Mensaje anterior",
+    "Search" : "Buscar",
+    "Refresh" : "Recargar",
     "Connect your mail account" : "Conecte su cuenta de correo",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Nextcloud Mail" : "Correo de Nextcloud",
