@@ -10,6 +10,7 @@ OC.L10N.register(
     "Password" : "Contraseña",
     "IMAP Host" : "Servidor IMAP",
     "None" : "Ninguno",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "Puerto IMAP",
     "IMAP User" : "Usuario IMAP",
@@ -18,19 +19,27 @@ OC.L10N.register(
     "SMTP Port" : "Puerto SMTP",
     "SMTP User" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar",
     "Connect" : "Conectar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
     "Keyboard shortcuts" : "Atajos del teclado",
+    "Select account" : "Selecciona la cuenta",
+    "Copy" : "Copiar",
     "Subject" : "Asunto",
-    "Sending …" : "Enviando ...",
-    "Message sent!" : "¡Mensaje enviado!",
-    "Send" : "Enviar",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
+    "Sending …" : "Enviando ...",
+    "Go back" : "Regresar",
+    "Retry" : "Reintentar",
+    "Message sent!" : "¡Mensaje enviado!",
+    "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "No messages in this folder" : "No hay mensajes en esta carpeta",
+    "Mark read" : "Marcar como leído",
     "Delete" : "Borrar",
+    "Reply" : "Responder",
+    "Forward" : "Adelante",
     "Could not load your message" : "No fue posible cargar tu mensaje",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
@@ -40,8 +49,15 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "New message" : "Mensaje nuevo",
     "Settings" : "Configuraciones ",
+    "Delete account" : "Borrar cuenta",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Compactar carpetas",
+    "Mark all as read" : "Marcar todos como leídos",
+    "Signature" : "Firma",
+    "General" : "General",
+    "User" : "Ususario",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -54,7 +70,6 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
     "Nextcloud Mail" : "Correo Nextcloud",
-    "All inboxes" : "Todos los buzones de entrada",
     "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
     "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
