@@ -8,6 +8,8 @@ OC.L10N.register(
     "Mail Address" : "E-posti aadress",
     "Password" : "Parool",
     "IMAP Host" : "IMAP server",
+    "None" : "Pole",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP port",
     "IMAP User" : "IMAP kasutaja",
@@ -16,22 +18,38 @@ OC.L10N.register(
     "SMTP Port" : "SMTP port",
     "SMTP User" : "SMTP kasutaja",
     "SMTP Password" : "SMTP parool",
+    "Save" : "Salvesta",
     "Connect" : "Ühenda",
     "Keyboard shortcuts" : "Klaviatuuri otseteed",
+    "Copy" : "Kopeeri",
     "Subject" : "Teema",
     "Sending …" : "Saadan ...",
+    "Go back" : "Mine tagasi",
+    "Retry" : "Proovi uuesti",
     "Message sent!" : "Sõnum on saadetud!",
     "Send" : "Saada",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
+    "Mark read" : "Märgi loetuks",
     "Delete" : "Kustuta",
+    "Reply" : "Vasta",
+    "Forward" : "Edasi",
     "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
     "New message" : "Uus sõnum",
     "Settings" : "Seaded",
+    "Add folder" : "Add folder",
+    "Delete account" : "Kustuta konto",
     "Show all folders" : "Näita kõiki kaustu",
+    "Mark all as read" : "Märgi loetuks",
+    "Signature" : "Allkiri",
+    "General" : "Üldine",
+    "User" : "Kasutaja",
+    "Host" : "Host",
+    "Port" : "Port",
     "Search" : "Otsi",
     "Refresh" : "Värskenda",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Error loading message" : "Tõrge kirja laadimisel",
-    "Forwarding to %s" : "Edasta %s"
+    "Forwarding to %s" : "Edasta %s",
+    "Redirect" : "Suunamine"
 },
 "nplurals=2; plural=(n != 1);");
