@@ -6,16 +6,21 @@ OC.L10N.register(
     "Name" : "نام",
     "Password" : "گذرواژه",
     "None" : "هیچ‌کدام",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "شروع TLS",
     "SMTP Password" : "رمز عبور SMTP",
     "Save" : "ذخیره",
     "Connect" : "اتصال",
     "Keyboard shortcuts" : "میان بر صفحه ی کلید",
+    "Select account" : "حساب را انتخاب کنید",
     "Copy" : "کپی کردن",
     "Sending …" : "در حال ارسال ...",
+    "Retry" : "تلاش دوباره",
     "Message sent!" : "پیام ارسال شد!",
     "Send" : "ارسال",
     "Delete" : "حذف",
     "Reply" : "پاسخ",
+    "Forward" : "فرستادن",
     "Choose a folder to store the attachment in" : "لطفا پوشه ای را برای ذخیره سازی ضمیمه انتخاب کنید",
     "Settings" : "تنظیمات",
     "Add folder" : "Add folder",
