@@ -32,6 +32,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Etsitkö tapaa salata sähköpostisi? Asenna Mailvelope-selainlaajennus!",
+    "Select account" : "Valitse tili",
+    "Copy" : "Kopioi",
     "Subject" : "Aihe",
     "Saving draft …" : "Tallennetaan luonnosta…",
     "Draft saved" : "Luonnos tallennettu",
@@ -71,17 +73,23 @@ OC.L10N.register(
     "New message" : "Uusi viesti",
     "Settings" : "Asetukset",
     "Edit account" : "Muokkaa tiliä",
-    "Delete account" : "Poista tili",
     "Add folder" : "Lisää kansio",
+    "Delete account" : "Poista tili",
     "Show all folders" : "Näytä kaikki kansiot",
     "Collapse folders" : "Supista kansiot",
     "Mark all as read" : "Merkitse kaikki luetuiksi",
+    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
     "Add subfolder" : "Lisää alikansio",
     "{total} messages" : "{total} viestiä",
+    "Loading …" : "Ladataan…",
     "Could not load your draft" : "Luonnosta ei voitu ladata",
     "No message selected" : "Viestiä ei ole valittu",
     "Signature" : "Allekirjoitus",
     "Save signature" : "Tallenna allekirjoitus",
+    "General" : "Yleiset",
+    "User" : "Käyttäjä",
+    "Host" : "Palvelin",
+    "Port" : "Portti",
     "Account settings" : "Tilin asetukset",
     "Change name" : "Vaihda nimi",
     "Mail server" : "Sähköpostipalvelin",
