@@ -10,6 +10,7 @@ OC.L10N.register(
     "Password" : "ססמה",
     "IMAP Host" : "מארח IMAP",
     "None" : "ללא",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "פתחת IMAP",
     "IMAP User" : "משתמש IMAP",
@@ -18,19 +19,27 @@ OC.L10N.register(
     "SMTP Port" : "פתחת SMTP",
     "SMTP User" : "משתמש SMTP",
     "SMTP Password" : "ססמת SMTP",
+    "Save" : "שמור",
     "Connect" : "התחברות",
     "Add mail account" : "הוספת חשבון דוא״ל",
     "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
     "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Select account" : "בחר חשבון",
+    "Copy" : "העתק",
     "Subject" : "נושא",
     "Upload attachment" : "העלאת קובץ מצורף",
     "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
     "Sending …" : "שולח...",
+    "Go back" : "חזרה",
+    "Retry" : "ניסיון חוזר",
     "Message sent!" : "הודעה נשלחה!",
     "Send" : "שליחה",
     "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
     "No messages in this folder" : "אין הודעות בתיקייה זו",
+    "Mark read" : "סימון כנקרא",
     "Delete" : "מחיקה",
+    "Reply" : "תגובה",
+    "Forward" : "העברה",
     "Could not load your message" : "לא ניתן לטעון את ההודעה שלך",
     "Import into calendar" : "ייבוא ליומן",
     "Download attachment" : "הורדת קובץ מצורף",
@@ -40,8 +49,16 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
     "New message" : "הודעה חדשה",
     "Settings" : "הגדרות",
+    "Add folder" : "הוספת תיקייה",
+    "Delete account" : "מחיקת חשבון",
     "Show all folders" : "הצגת כל התיקיות",
     "Collapse folders" : "קיווץ תיקיות",
+    "Mark all as read" : "סימון הכול כנקרא",
+    "Signature" : "חתימה",
+    "General" : "כללי",
+    "User" : "משתמש",
+    "Host" : "מארח",
+    "Port" : "פתחה",
     "Speed up your Mail experience with these quick shortcuts." : "ניתן להאיץ את חוויית הדוא״ל שלך עם קיצורי המקלדת הזריזים האלו.",
     "Compose new message" : "כתיבת הודעה חדשה",
     "Newer message" : "הודעה חדשה יותר",
