@@ -30,6 +30,8 @@ OC.L10N.register(
     "Add mail account" : "E-mail fiók hozzáadás",
     "Use Gravatar and favicon avatars" : "Gravatar és favicon avatarok használata",
     "Keyboard shortcuts" : "Gyorsbillentyűk",
+    "Select account" : "Fiók kiválasztása",
+    "Copy" : "Másolás",
     "Subject" : "Tárgy",
     "Saving draft …" : "Vázlat mentése ...",
     "Draft saved" : "Vázlat elmentve",
@@ -54,6 +56,8 @@ OC.L10N.register(
     "Report this bug" : "A hiba bejelentése",
     "Loading messages" : "Üzenetek betöltése",
     "Not found" : "Nem található",
+    "Reply" : "Válasz",
+    "Forward" : "Tovább",
     "Could not load your message" : "Nem lehet betölteni az üzenetedet",
     "Import into calendar" : "Betöltés a naptárba",
     "Download attachment" : "Melléklet letöltése",
@@ -64,12 +68,20 @@ OC.L10N.register(
     "New message" : "Új üzenet",
     "Settings" : "Beállítások",
     "Add folder" : "Mappa hozzáadás",
+    "Delete account" : "Fiók törlése",
     "Show all folders" : "Minden mappa megjelenítése",
     "Collapse folders" : "Mappák összecsukása",
     "Mark all as read" : "Az összes megjelölése olvasottként",
+    "Mark all messages of this folder as read" : "A mappában található összes üzenet megjelölése olvasottként",
     "Add subfolder" : "Almappa hozzáadás",
+    "Loading …" : "Töltés ...",
     "No message selected" : "Nincs kiválasztott üzenet",
     "Signature" : "Aláírás",
+    "General" : "Általános",
+    "Email address" : "E-mail cím",
+    "User" : "Felhasználó",
+    "Host" : "Kiszolgáló",
+    "Port" : "Port",
     "Mail server" : "Levelezőszerver",
     "Speed up your Mail experience with these quick shortcuts." : "Gyorsítsd fel a levelezési élményedet ezekkel a rövidítésekkel.",
     "Compose new message" : "Új üzenet írása",
