@@ -10,6 +10,7 @@ OC.L10N.register(
     "Password" : "პაროლი",
     "IMAP Host" : "IMAP ჰოსტი",
     "None" : "არც ერთი",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP პორტი",
     "IMAP User" : "IMAP მომხმარებელი",
@@ -18,18 +19,26 @@ OC.L10N.register(
     "SMTP Port" : "SMTP პორტი",
     "SMTP User" : "SMTP მომხმარებელი",
     "SMTP Password" : "SMTP პაროლი",
+    "Save" : "შენახვა",
     "Connect" : "დაკავშირება",
     "Add mail account" : "საფოსტო ანგარიშის დამატება",
     "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
+    "Select account" : "აირჩიეთ ანგარიში",
+    "Copy" : "კოპირება",
     "Subject" : "სათაური",
     "Upload attachment" : "დანართის ატვირთვა",
     "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
     "Sending …" : "იგზავნება …",
+    "Go back" : "უკან დაბრუნება",
+    "Retry" : "ვცადოთ ახლიდან",
     "Message sent!" : "წერილი გაგზავნილია!",
     "Send" : "გაგზავნა",
     "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
+    "Mark read" : "მონიშნეთ წაკითხულად",
     "Delete" : "გაუქმება",
+    "Reply" : "პასუხი",
+    "Forward" : "წინ",
     "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
     "Import into calendar" : "იმპორტი კალენდარში",
     "Download attachment" : "დანართის გადმოწერა",
@@ -39,8 +48,16 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
     "New message" : "ახალი წერილი",
     "Settings" : "პარამეტრები",
+    "Add folder" : "Add folder",
+    "Delete account" : "ანგარიშის გაუქმება",
     "Show all folders" : "ყველა დირექტორიის ჩვენება",
     "Collapse folders" : "დირექტორიების კოლაფსი",
+    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
+    "Signature" : "ხელმოწერა",
+    "General" : "ზოგადი",
+    "User" : "მომხმარებელი",
+    "Host" : "ჰოსტი",
+    "Port" : "პორტი",
     "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
     "Compose new message" : "ახალი წერილის შედგენა",
     "Newer message" : "უფრო ახალი წერილი",
