@@ -97,6 +97,13 @@ OC.L10N.register(
     "Signature" : "Parašas",
     "Signature …" : "Parašas…",
     "Save signature" : "Įrašyti parašą",
+    "Could not create event" : "Nepavyko sukurti įvykio",
+    "Airplane" : "Lėktuvas",
+    "Reservation {id}" : "Rezervacija {id}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Skrydis {flightNr} iš {depAirport} į {arrAirport}",
+    "Train" : "Traukinys",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
     "Mail app" : "Pašto programėlė",
     "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
     "Email: {email}" : "El. paštas: {email}",
