@@ -9,6 +9,7 @@ OC.L10N.register(
     "Password" : "Parole",
     "IMAP Host" : "IMAP serveris",
     "None" : "Neviens",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "IMAP Port",
     "IMAP User" : "IMAP lietotājs",
@@ -17,13 +18,23 @@ OC.L10N.register(
     "SMTP Port" : "SMTP Port",
     "SMTP User" : "SMTP lietotājs",
     "SMTP Password" : "SMTP parole",
+    "Save" : "Saglabāt",
     "Connect" : "Savienoties",
     "Add mail account" : "Pievienot e-pasta kontu",
+    "Keyboard shortcuts" : "Tastatūras saīsnes",
+    "Select account" : "Izvēlieties kontu",
+    "Copy" : "Kopēt",
     "Subject" : "Temats",
+    "Add attachment from Files" : "Pievienot pielikumu no failiem",
     "Sending …" : "Sūta …",
+    "Go back" : "Atpakaļ",
+    "Retry" : "Mēģināt vēlreiz",
     "Message sent!" : "Vēstule aizsūtīta!",
     "Send" : "Sūtīt",
     "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
+    "Delete" : "Dzēst",
+    "Reply" : "Atbildēt",
+    "Forward" : "Turpināt",
     "Import into calendar" : "Importēt kalendārā",
     "Download attachment" : "Lejupielādēt pielikumu",
     "Save to Files" : "Saglabāt uz Datnes",
@@ -32,8 +43,17 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Attēli tiek bloķēti, lai aizsargātu jūsu konfidencialitāti.",
     "New message" : "Jauna ziņa",
     "Settings" : "Iestatījumi",
+    "Add folder" : "Pievienot mapi",
+    "Delete account" : "Dzēst kontu",
     "Show all folders" : "Rādīt visas mapes",
     "Collapse folders" : "Sakļaut mapes",
+    "Signature" : "Paraksts",
+    "General" : "Vispārīgs",
+    "User" : "Lietotājs",
+    "Host" : "Resursdators",
+    "Port" : "Ports",
+    "Search" : "Meklēt",
+    "Refresh" : "Atsvaidzināt",
     "Connect your mail account" : "Pievienojiet savu e-pasta kontu",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
