@@ -25,10 +25,13 @@ OC.L10N.register(
     "SMTP Port" : "SMTP-port",
     "SMTP User" : "SMTP-bruker",
     "SMTP Password" : "SMTP-passord",
+    "Save" : "Lagre",
     "Connect" : "Koble til",
     "Add mail account" : "Legg til e-postkonto",
     "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
     "Keyboard shortcuts" : "Tastatursnarveier",
+    "Select account" : "Velg konto",
+    "Copy" : "Kopier",
     "Subject" : "Emne",
     "Saving draft …" : "Lagrer kladd…",
     "Draft saved" : "Kladd ble lagret",
@@ -52,6 +55,8 @@ OC.L10N.register(
     "Report this bug" : "Rapporter denne feilen",
     "Loading messages" : "Henter meldinger",
     "Not found" : "Ikke funnet",
+    "Reply" : "Svar",
+    "Forward" : "Fremover",
     "Could not load your message" : "Kunne ikke laste meldingene dine",
     "Import into calendar" : "Importer til kalender",
     "Download attachment" : "Last ned vedlegg",
@@ -63,9 +68,18 @@ OC.L10N.register(
     "Show images from this\tsender" : "Vis bilder fra denne avsenderen",
     "New message" : "Ny melding",
     "Settings" : "Innstillinger",
+    "Add folder" : "Legg til mappe",
+    "Delete account" : "Slett konto",
     "Show all folders" : "Vis alle mapper",
     "Collapse folders" : "Skjul mapper",
+    "Mark all as read" : "Marker alle som lest",
+    "Loading …" : "Laster...",
     "Could not load your draft" : "Kunne ikke laste inn denne kladden",
+    "Signature" : "Signatur",
+    "General" : "Generell",
+    "User" : "Bruker",
+    "Host" : "Server",
+    "Port" : "Port",
     "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
     "Compose new message" : "Lag ny melding",
     "Newer message" : "Nyere melding",
