@@ -5,15 +5,25 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "A deteção automática falhou. Por favor, utilize o modo manual",
     "Creating account failed: " : "Não foi possível criar a conta:",
     "Name" : "Nome",
+    "Mail Address" : "Endereço de Correio",
+    "Password" : "Palavra-passe",
     "IMAP Host" : "Anfitrião de IMAP",
+    "None" : "Nenhum",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
     "SMTP Host" : "Anfitrião de SMTP",
+    "SMTP Password" : "Palavra-passe SMTP",
+    "Save" : "Guardar",
     "Connect" : "Ligar",
+    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Copy" : "Copiar",
     "Subject" : "Assunto",
     "Saving draft …" : "A guardar rascunho ...",
     "Draft saved" : "Rascunho guardado",
     "Uploading attachments …" : "A enviar anexos ...",
     "Sending …" : "A enviar...",
     "Go back" : "Voltar",
+    "Retry" : "Repetir",
     "Message sent!" : "Mensagem enviada!",
     "Reply sent!" : "Resposta enviada!",
     "Send" : "Enviar",
@@ -30,11 +40,20 @@ OC.L10N.register(
     "Save to Files" : "Guardar em Ficheiros",
     "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
     "Save all to Files" : "Guardar todos em Ficheiros",
+    "Settings" : "Definições",
     "Edit account" : "Editar conta",
+    "Add folder" : "Add folder",
     "Delete account" : "Apagar conta",
     "Show all folders" : "Mostrar todas as pastas",
     "Collapse folders" : "Ocultar pastas",
     "Mark all as read" : "Marcar todas como lidas",
+    "Signature" : "Assinatura",
+    "General" : "Geral",
+    "User" : "Utilizador",
+    "Host" : "Anfitrião",
+    "Port" : "Porta",
+    "Search" : "Pesquisar",
+    "Refresh" : "Atualizar",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Error loading message" : "Erro ao carregar a mensagem",
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redireccionado dentro de segundos.",
