@@ -88,8 +88,8 @@ OC.L10N.register(
     "New message" : "Novo sporočilo",
     "Settings" : "Nastavitve",
     "Edit account" : "Uredi račun",
-    "Delete account" : "Izbriši račun",
     "Add folder" : "Dodaj mapo",
+    "Delete account" : "Izbriši račun",
     "Show all folders" : "Pokaži vse mape",
     "Collapse folders" : "Zloži mape",
     "Mark all as read" : "Označi vse kot prebrano",
@@ -105,6 +105,10 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "K besedilu novih sporočil in odgovorov je dodan podpis.",
     "Signature …" : "Podpis ...",
     "Save signature" : "Shrani podpis",
+    "General" : "Splošno",
+    "User" : "Uporabnik",
+    "Host" : "Gostitelj",
+    "Port" : "Vrata",
     "Account settings" : "Nastavitve računa",
     "Change name" : "Spremeni ime",
     "Mail server" : "Poštni strežnik",
