@@ -9,6 +9,7 @@ OC.L10N.register(
     "Password" : "Fjalëkalimi",
     "IMAP Host" : "Strehë IMAP",
     "None" : "Asnjë",
+    "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "IMAP Port" : "Porta IMAP",
     "IMAP User" : "Përdorues IMAP",
@@ -17,16 +18,25 @@ OC.L10N.register(
     "SMTP Port" : "Porta SMTP",
     "SMTP User" : "Përdoruesi i SMTP",
     "SMTP Password" : "Fjalëkalimi SMTP",
+    "Save" : "Ruaj",
     "Connect" : "Lidhu",
     "Add mail account" : "Shto llogarinë e postës elektronike",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
+    "Select account" : "Përzgjidhni llogari",
+    "Copy" : "Kopjo",
     "Subject" : "Temë",
     "Upload attachment" : "Ngarko bashkëngjitje",
+    "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
     "Sending …" : "Po dërgohet …",
+    "Go back" : "Shko prapa",
+    "Retry" : "Riprovoni",
     "Message sent!" : "Mesazhi u dërgua!",
     "Send" : "Dërgo",
     "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
+    "Mark read" : "Shëno të lexuar",
     "Delete" : "Fshij",
+    "Reply" : "Përgjigju",
+    "Forward" : "Përpara",
     "Import into calendar" : "Importo në kalendar",
     "Download attachment" : "Shkarko bashkëlidhjen",
     "Save to Files" : "Ruaje te Skedarët",
@@ -35,8 +45,16 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
     "New message" : "Mesazh i ri",
     "Settings" : "Konfigurimet",
+    "Add folder" : "Shto dosje",
+    "Delete account" : "Fshij llogarinë",
     "Show all folders" : "Shfaqi krejt dosjet",
     "Collapse folders" : "Tkurri dosjet",
+    "Mark all as read" : "Shënoji krejt si të lexuar",
+    "Signature" : "Nënshkrimi",
+    "General" : "Të përgjithshme",
+    "User" : "Përdorues",
+    "Host" : "Strehë",
+    "Port" : "Porta",
     "Speed up your Mail experience with these quick shortcuts." : "Përmirësoni përvojën tuaj në Mail me këto shkurtore të shpejta.",
     "Newer message" : "Mesazhe më të reja",
     "Older message" : "Mesazhe më të vjetra",
