@@ -4,13 +4,22 @@ OC.L10N.register(
     "Mail" : "Pošta",
     "Name" : "naziv",
     "Password" : "Password",
+    "None" : "Ništa",
     "Save" : "Save",
+    "Connect" : "Poveži se",
+    "Select account" : "Označite nalog",
+    "Copy" : "Kopiraj",
     "Send" : "Pošalji",
     "Delete" : "Delete",
+    "Reply" : "Odgovori",
+    "Forward" : "Prosledi",
     "Settings" : "Postavke",
     "Add folder" : "Add folder",
     "Delete account" : "Delete account",
+    "Mark all as read" : "Označi sve kao pročitano",
+    "General" : "Opšte",
     "User" : "User",
-    "Search" : "Search"
+    "Search" : "Search",
+    "Refresh" : "Osveži"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
