@@ -4,14 +4,34 @@ OC.L10N.register(
     "Mail" : "จดหมาย",
     "Auto detect failed. Please use manual mode." : "ตรวจจับอัตโนมัติล้มเหลว กรุณาใช้โหมดควบคุมด้วยตนเอง",
     "Creating account failed: " : "สร้างบัญชีล้มเหลว:",
+    "Name" : "ชื่อ",
+    "Password" : "รหัสผ่าน",
+    "None" : "ไม่มี",
+    "SMTP Password" : "รหัสผ่าน SMTP",
+    "Save" : "บันทึก",
     "Connect" : "เชื่อมต่อ",
+    "Keyboard shortcuts" : "ปุ่มลัด",
+    "Copy" : "คัดลอก",
     "Sending …" : "กำลังส่ง ...",
+    "Go back" : "กลับไป",
     "Message sent!" : "ส่งข้อความ!",
     "Send" : "ส่ง",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
+    "Delete" : "ลบ",
+    "Reply" : "ตอบกลับ",
     "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บสิ่งที่แนบมาใน",
+    "Settings" : "ตั้งค่า",
+    "Add folder" : "Add folder",
+    "Delete account" : "Delete account",
     "Show all folders" : "แสดงโฟลเดอร์ทั้งหมด",
     "Collapse folders" : "ยุบโฟลเดอร์",
+    "Mark all as read" : "เลือกอ่านทั้งหมด",
+    "General" : "ทั่วไป",
+    "User" : "User",
+    "Host" : "โฮสต์",
+    "Port" : "พอร์ต",
+    "Search" : "Search",
+    "Refresh" : "รีเฟรช",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Error loading message" : "กิดข้อผิดพลาดในการโหลด",
     "Redirect" : "เปลี่ยนเส้นทาง",
