@@ -100,7 +100,7 @@ OC.L10N.register(
     "Add subfolder" : "添加子文件夹",
     "{total} messages" : "{total} 封邮件",
     "{unread} unread of {total}" : "总共 {total} 封邮件，{unread} 封未读邮件",
-    "Loading …" : "加载中...",
+    "Loading …" : "正在加载...",
     "Could not load your draft" : "无法加载您的草稿",
     "Could not load original message" : "无法加载初始消息",
     "No message selected" : "没有选择消息",
@@ -108,6 +108,15 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
     "Signature …" : "签名...",
     "Save signature" : "保存签名",
+    "Import into {calendar}" : "导入到 {calendar}",
+    "Event imported into {calendar}" : "事件导入到 {calendar}",
+    "Could not create event" : "无法建立事件",
+    "Airplane" : "飞机",
+    "Reservation {id}" : "预订 {id}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} 航班从 {depAirport} 飞往 {arrAirport}",
+    "Train" : "火车",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 从 {depStation} 到 {arrStation}",
+    "Train from {depStation} to {arrStation}" : "火车从 {depStation} 到 {arrStation}",
     "Mail app" : "邮件应用",
     "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
     "Email: {email}" : "电子邮件：{email}",
@@ -137,6 +146,7 @@ OC.L10N.register(
     "Refresh" : "刷新",
     "Connect your mail account" : "连接您的邮件账号",
     "Unexpected error during account creation" : "创建账号时发生意外错误",
+    "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
     "Nextcloud Mail" : "Nextcloud 邮件",
