@@ -31,15 +31,21 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
     "Keyboard shortcuts" : "快速鍵",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "需要一個方式加密您的電子郵件嗎？請安裝 Mailvelope 瀏覽器擴充程式",
+    "Select account" : "選擇帳號",
+    "Copy" : "複製",
     "Subject" : "主旨",
     "Upload attachment" : "上傳附件",
     "Add attachment from Files" : "從雲端檔案中加入附件",
     "Sending …" : "傳送中…",
+    "Go back" : "返回",
+    "Retry" : "重試",
     "Message sent!" : "信件已寄出",
     "Send" : "傳送",
     "Choose a file to add as attachment" : "選擇檔案作為附件",
     "No messages in this folder" : "此收件匣中沒有信件",
     "Delete" : "刪除",
+    "Reply" : "回覆",
+    "Forward" : "向前",
     "Could not load your message" : "無法載入您的信件",
     "Import into calendar" : "匯入到日曆",
     "Download attachment" : "下載附檔",
@@ -49,8 +55,17 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入",
     "New message" : "新信件",
     "Settings" : "設定",
+    "Add folder" : "新增資料夾",
+    "Delete account" : "刪除帳號",
     "Show all folders" : "顯示所有收件匣",
     "Collapse folders" : "收合收件匣",
+    "Mark all as read" : "全部標示為已閱讀",
+    "Loading …" : "載入中 ...",
+    "Signature" : "簽章",
+    "General" : "一般",
+    "User" : "使用者",
+    "Host" : "主機",
+    "Port" : "連接埠",
     "Speed up your Mail experience with these quick shortcuts." : "使用快速鍵來加速您的操作體驗",
     "Compose new message" : "撰寫新信件",
     "Newer message" : "較新的信件",
