@@ -29,7 +29,6 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Model;
 
-use Closure;
 use Exception;
 use Horde_Imap_Client;
 use Horde_Imap_Client_Data_Envelope;
@@ -48,7 +47,6 @@ use OCA\Mail\Service\Html;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\Files\File;
 use OCP\Files\SimpleFS\ISimpleFile;
-use OCP\Util;
 use function base64_encode;
 use function mb_convert_encoding;
 
@@ -413,6 +411,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	public function jsonSerialize(): array {
 		return [
 			'id' => $this->getUid(),
+			'messageId' => $this->getMessageId(),
 			'from' => $this->getFrom()->jsonSerialize(),
 			'to' => $this->getTo()->jsonSerialize(),
 			'cc' => $this->getCC()->jsonSerialize(),
@@ -420,6 +419,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 			'subject' => $this->getSubject(),
 			'dateInt' => $this->getSentDate()->getTimestamp(),
 			'flags' => $this->getFlags(),
+			'hasHtmlBody' => $this->hasHtmlMessage,
 		];
 	}
 
